#!/bin/sh
# This wrapper script is intended to be submitted to PBS to support
# communicating jobs.
#
# This script uses the following environment variables set by the submit MATLAB code:
# MDCE_CMR            - the value of ClusterMatlabRoot (may be empty)
# MDCE_MATLAB_EXE     - the MATLAB executable to use
# MDCE_MATLAB_ARGS    - the MATLAB args to use
#
# The following environment variables are forwarded through mpiexec:
# MDCE_DECODE_FUNCTION     - the decode function to use
# MDCE_STORAGE_LOCATION    - used by decode function 
# MDCE_STORAGE_CONSTRUCTOR - used by decode function 
# MDCE_JOB_LOCATION        - used by decode function 

# Copyright 2006-2012 The MathWorks, Inc.

MPIEXEC_CODE=0
###################################
## CUSTOMIZATION MAY BE REQUIRED ##
###################################
# This script assumes that SSH is set up to work without passwords between
# all nodes on the cluster.
# You may wish to modify SSH_COMMAND to include any additional ssh options that
# you require.

runMpiexec() {
    INTEL_MPIEXEC=/usr/local/intel/impi/4.0.3.008/intel64/bin/mpiexec.hydra

    # As a debug stage: echo the command line...
    echo ${INTEL_MPIEXEC} -print-rank-map -n ${MDCE_TOTAL_TASKS} -bootstrap rsh -bootstrap-exec /usr/local/bin/pbsrsh -hostfile ${PBS_NODEFILE} \
        -envlist MATLABPATH,MDCE_DECODE_FUNCTION,MDCE_STORAGE_LOCATION,MDCE_STORAGE_CONSTRUCTOR,MDCE_JOB_LOCATION,MDCE_DEBUG,MDCE_LICENSE_NUMBER,MLM_WEB_LICENSE,MLM_WEB_USER_CRED,MLM_WEB_ID \
        ${MDCE_MATLAB_EXE} ${MDCE_MATLAB_ARGS}
    echo $MDCE_LICENSE_NUMBER
    
    # ...and then execute it
    eval ${INTEL_MPIEXEC} -verbose -print-rank-map -n ${MDCE_TOTAL_TASKS} -bootstrap rsh -bootstrap-exec /usr/local/bin/pbsrsh -hostfile ${PBS_NODEFILE} \
        -envlist MATLABPATH,MDCE_DECODE_FUNCTION,MDCE_STORAGE_LOCATION,MDCE_STORAGE_CONSTRUCTOR,MDCE_JOB_LOCATION,MDCE_DEBUG,MDCE_LICENSE_NUMBER,MLM_WEB_LICENSE,MLM_WEB_USER_CRED,MLM_WEB_ID \
        ${MDCE_MATLAB_EXE} ${MDCE_MATLAB_ARGS}
    
     MPIEXEC_CODE=${?}
}

# Define the order in which we execute the stages defined above
MAIN() {
    cat ${PBS_NODEFILE}
    export MATLABPATH=/usr/local/MATLAB/OSC/distcomp/mpi:$MATLABPATH
    runMpiexec
    exit ${MPIEXEC_CODE}
}

# Call the MAIN loop
MAIN
